@@ -1,12 +1,12 @@
 # -*- coding: utf-8 -*-
-from _stories.exceptions import FailureError
-from _stories.summary import FailureSummary
-from _stories.summary import SuccessSummary
+from _stories.exceptions import make_failure_error
+from _stories.summary import make_failure_summary
+from _stories.summary import make_success_summary
 
 
 class Call(object):
     def got_failure(self, ctx, method_name, reason):
-        raise FailureError(reason)
+        raise make_failure_error(reason)
 
     def got_result(self, value):
         return value
@@ -20,10 +20,10 @@ class Run(object):
         self.protocol = protocol
 
     def got_failure(self, ctx, method_name, reason):
-        return FailureSummary(self.protocol, ctx, method_name, reason)
+        return make_failure_summary(self.protocol, ctx, method_name, reason)
 
     def got_result(self, value):
-        return SuccessSummary(self.protocol, value)
+        return make_success_summary(self.protocol, value)
 
     def finished(self):
-        return SuccessSummary(self.protocol, None)
+        return make_success_summary(self.protocol, None)
